@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class IntroductionWebEnginePage : public QWebEnginePage
     Q_OBJECT
 public:
     explicit IntroductionWebEnginePage(QObject *parent = nullptr);
-    ~IntroductionWebEnginePage();
+    ~IntroductionWebEnginePage() override;
 Q_SIGNALS:
     void urlClicked(const QUrl &url);
 protected:
